@@ -12,6 +12,13 @@
 
 import sys
 
+verbose = 0
+
+try:
+    import json
+except ImportError:
+    import simplejson as json
+
 
 class BaseException(Exception):
     """An error occurred."""
@@ -38,6 +45,30 @@ class HTTPException(BaseException):
     """Base exception for all HTTP-derived exceptions."""
     code = 'N/A'
 
+    def __init__(self, message=None):
+        super(HTTPException, self).__init__(message)
+        try:
+            self.error = json.loads(message)
+            if 'error' not in self.error:
+                raise KeyError('Key "error" not exists')
+        except KeyError:
+            # NOTE(jianingy): If key 'error' happens not exist,
+            # self.message becomes no sense. In this case, we
+            # return doc of current exception class instead.
+            self.error = {'error':
+                          {'message': self.__class__.__doc__}}
+        except Exception:
+            self.error = {'error':
+                          {'message': self.message or self.__class__.__doc__}}
+
+    def __str__(self):
+        message = self.error['error'].get('message', 'Internal Error')
+        if verbose:
+            traceback = self.error['error'].get('traceback', '')
+            return 'ERROR: %s\n%s' % (message, traceback)
+        else:
+            return 'ERROR: %s' % message
+
 
 class HTTPMultipleChoices(HTTPException):
     code = 300
